@@ -33,11 +33,20 @@ from SigProfilerAssignment import single_sample as ss
 from scipy.spatial.distance import correlation as cor
 from alive_progress import alive_bar
 
-def getProcessAvg(samples, genome_build="GRCh37", cosmic_version=3.2,signature_database=None,connected_sigs = True):
+def getProcessAvg(samples, genome_build="GRCh37", cosmic_version=3.3, signature_database=None, connected_sigs = True, exome=False):
     paths = spa.__path__[0]
     
+    if genome_build == "GRCh37" or genome_build == "GRCh38" or genome_build == "mm9" or genome_build == "mm10" or genome_build == "rn6":
+        genome_build = genome_build
+    else:
+        print("The selected genome build is "+str(genome_build)+". COSMIC signatures are available only for GRCh37/38, mm9/10 and rn6 genomes. So, the genome build is reset to GRCh37.")
+        genome_build = "GRCh37"
+
     if samples.shape[0]==96:
-        sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_SBS_"+genome_build+".txt", sep="\t", index_col=0)
+        if exome==False:
+            sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_SBS_"+genome_build+".txt", sep="\t", index_col=0)
+        else:
+            sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_SBS_"+genome_build+"_exome.txt", sep="\t", index_col=0)
         signames = sigDatabase.columns   
         
     elif samples.shape[0]==288:
@@ -45,11 +54,14 @@ def getProcessAvg(samples, genome_build="GRCh37", cosmic_version=3.2,signature_d
         signames = sigDatabase.columns
         
     elif samples.shape[0]==1536:
-        sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+"GRCh37"+"/COSMIC_v"+str(cosmic_version)+"_SBS"+str(samples.shape[0])+"_GRCh37.txt", sep="\t", index_col=0)
+        sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/GRCh37/COSMIC_v"+str(cosmic_version)+"_SBS"+str(samples.shape[0])+"_GRCh37.txt", sep="\t", index_col=0)
         signames = sigDatabase.columns
     
     elif samples.shape[0]==78:
-        sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_DBS_"+genome_build+".txt", sep="\t", index_col=0)
+        if exome==False:
+            sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_DBS_"+genome_build+".txt", sep="\t", index_col=0)
+        else:
+            sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/"+genome_build+"/COSMIC_v"+str(cosmic_version)+"_DBS_"+genome_build+"_exome.txt", sep="\t", index_col=0)
         signames = sigDatabase.columns
         connected_sigs=False
         
@@ -60,7 +72,7 @@ def getProcessAvg(samples, genome_build="GRCh37", cosmic_version=3.2,signature_d
         
     elif samples.shape[0]==48:
         if cosmic_version < 3.3:
-            print("The selected cosmic version is"+str(cosmic_version)+". CN signatures are available only for version 3.3. So, the cosmic version is reset to v3.3.")
+            print("The selected cosmic version is "+str(cosmic_version)+". CN signatures are available only for version 3.3. So, the cosmic version is reset to v3.3.")
             cosmic_version=3.3
         sigDatabase = pd.read_csv(paths+"/data/Reference_Signatures/GRCh37/COSMIC_v"+str(cosmic_version)+"_CN_GRCh37.txt", sep="\t",index_col=0)
         signames = sigDatabase.columns
@@ -157,7 +169,7 @@ def get_items_from_index(x,y):
             pass
     return z
 
-def signature_decomposition(signatures, mtype, directory, genome_build="GRCh37", cosmic_version=3.2,signature_database=None, add_penalty=0.05, remove_penalty=0.01, mutation_context=None, connected_sigs=True, make_decomposition_plots=True, originalProcessAvg=None,new_signature_thresh_hold=0.8,sig_exclusion_list=[]):
+def signature_decomposition(signatures, mtype, directory, genome_build="GRCh37", cosmic_version=3.3,signature_database=None, add_penalty=0.05, remove_penalty=0.01, mutation_context=None, connected_sigs=True, make_decomposition_plots=True, originalProcessAvg=None,new_signature_thresh_hold=0.8,sig_exclusion_list=[],exome=False):
 
     originalProcessAvg = originalProcessAvg.reset_index()
     if not os.path.exists(directory+"/Solution_Stats"):
@@ -205,7 +217,7 @@ def signature_decomposition(signatures, mtype, directory, genome_build="GRCh37",
 
 
     if signature_database==None:
-        sigDatabase,signames,connected_sigs = getProcessAvg(signatures, genome_build, cosmic_version=cosmic_version)
+        sigDatabase,signames,connected_sigs = getProcessAvg(signatures, genome_build=genome_build, cosmic_version=cosmic_version, exome=exome)
         #processAvg = processAvg.set_index('Type').rename_axis('MutationType')
     else:
         try:
@@ -379,7 +391,7 @@ def signature_decomposition(signatures, mtype, directory, genome_build="GRCh37",
                 # Get the names of the columns for each dataframe
                 denovo_col_names = originalProcessAvg.columns
                 cosmic_col_names = sigDatabases_DF.columns
-                # Get the name for the MutationTypes column
+                # Get the name for the MutationType column
                 cosmic_mut_types_col = cosmic_col_names[0]
                 denovo_mut_types_col =  denovo_col_names[0]
                 # create lists of implemented columns
@@ -675,7 +687,7 @@ def make_final_solution(processAvg, allgenomes, allsigids, layer_directory, m, i
     processAvg= pd.DataFrame(processAvg.astype(float))
     processes = processAvg.set_index(index)
     processes.columns = allsigids
-    processes = processes.rename_axis("MutationsType", axis="columns")
+    processes = processes.rename_axis("MutationType", axis="columns")
     processes.to_csv(layer_directory+"/Signatures"+"/"+solution_prefix+"_"+"Signatures.txt", "\t", float_format='%.8f',index_label=[processes.columns.name]) 
     exposureAvg = pd.DataFrame(exposureAvg.astype(int))
     allsigids = np.array(allsigids)
@@ -881,7 +893,7 @@ def probabilities(W, H, index, allsigids, allcolnames):
         probs.columns = sigs
         col1 = [cols[i]]*len(rows)
         probs.insert(loc=0, column='Sample Names', value=col1)
-        probs.insert(loc=1, column='MutationTypes', value = rows)
+        probs.insert(loc=1, column='MutationType', value = rows)
         if i!=0:
             result = pd.concat([result, probs], axis=0)
         else:
